pub struct Config {Show 129 fields
pub fragment_prefix: String,
pub htmlmessage_deleted: Option<String>,
pub antispam_at: String,
pub antispamdomain: Option<String>,
pub language: String,
pub htmlsuffix: String,
pub mbox: Option<String>,
pub archives: Option<String>,
pub custom_archives: Option<String>,
pub about: Option<String>,
pub label: Option<String>,
pub dir: Option<String>,
pub defaultindex: String,
pub default_top_index: String,
pub mailcommand: String,
pub newmsg_command: String,
pub replymsg_command: String,
pub inreplyto_command: Option<String>,
pub mailto: Option<String>,
pub hmail: Option<String>,
pub domainaddr: Option<String>,
pub css: Option<String>,
pub icss_url: Option<String>,
pub mcss_url: Option<String>,
pub dateformat: Option<String>,
pub indexdateformat: Option<String>,
pub stripsubject: Option<String>,
pub link_to_replies: Option<String>,
pub quote_link_string: Option<String>,
pub ihtmlheader: Option<String>,
pub ihtmlfooter: Option<String>,
pub ihtmlhead: Option<String>,
pub ihtmlhelpup: Option<String>,
pub ihtmlhelplow: Option<String>,
pub ihtmlnavbar2up: Option<String>,
pub mhtmlheader: Option<String>,
pub mhtmlfooter: Option<String>,
pub attachmentlink: Option<String>,
pub bodyheader: Option<String>,
pub bodyheaderend: Option<String>,
pub bodyfooter: Option<String>,
pub unsafe_chars: Option<String>,
pub filename_base: Option<String>,
pub folder_by_date: Option<String>,
pub latest_folder: Option<String>,
pub base_url: Option<String>,
pub describe_folder: Option<String>,
pub delete_older: Option<String>,
pub delete_newer: Option<String>,
pub alts_text: Option<String>,
pub description: Option<String>,
pub theme: Option<String>,
pub append_filename: Option<String>,
pub txtsuffix: Option<String>,
pub email_address_obfuscation: bool,
pub i18n: bool,
pub i18n_body: bool,
pub overwrite: bool,
pub inlinehtml: bool,
pub readone: bool,
pub reverse: bool,
pub reverse_folders: bool,
pub showheaders: bool,
pub showbr: bool,
pub showreplies: bool,
pub indextable: bool,
pub iquotes: bool,
pub eurodate: bool,
pub gmtime: bool,
pub isodate: bool,
pub require_msgids: bool,
pub discard_dup_msgids: bool,
pub usemeta: bool,
pub uselock: bool,
pub ietf_mbox: bool,
pub linkquotes: bool,
pub monthly_index: bool,
pub yearly_index: bool,
pub spamprotect: bool,
pub spamprotect_id: bool,
pub attachmentsindex: bool,
pub usegdbm: bool,
pub writehaof: bool,
pub append: bool,
pub nonsequential: bool,
pub warn_surpressions: bool,
pub files_by_thread: bool,
pub href_detection: bool,
pub mbox_shortened: bool,
pub report_new_file: bool,
pub report_new_folder: bool,
pub use_sender_date: bool,
pub inline_addlink: bool,
pub iso2022jp: bool,
pub delete_incremental: bool,
pub showgenerator: bool,
pub show_warnings: bool,
pub increment: i32,
pub showhtml: i32,
pub show_msg_links: i32,
pub show_index_links: i32,
pub thrdlevels: i32,
pub dirmode: i32,
pub filemode: i32,
pub locktime: i32,
pub searchbackmsgnum: i32,
pub quote_hide_threshold: i32,
pub thread_file_depth: i32,
pub startmsgnum: i32,
pub msgsperfolder: i32,
pub save_alts: i32,
pub delete_level: i32,
pub progress: i32,
pub max_message_size: usize,
pub show_headers: HmList,
pub avoid_indices: HmList,
pub avoid_top_indices: HmList,
pub skip_headers: HmList,
pub text_types: HmList,
pub inline_types: HmList,
pub prefered_types: HmList,
pub ignore_types: HmList,
pub filter_out: HmList,
pub filter_require: HmList,
pub filter_out_full_body: HmList,
pub filter_require_full_body: HmList,
pub deleted: HmList,
pub expires: HmList,
pub delete_msgnum: HmList,
}Expand description
Complete runtime configuration for a hypermail archive run.
Controls input/output paths, HTML generation options, index types, spam protection, i18n, MIME handling, and template customization.
Fields
fragment_prefix: Stringhtmlmessage_deleted: Option<String>antispam_at: Stringantispamdomain: Option<String>language: Stringhtmlsuffix: Stringmbox: Option<String>archives: Option<String>custom_archives: Option<String>about: Option<String>label: Option<String>dir: Option<String>defaultindex: Stringdefault_top_index: Stringmailcommand: Stringnewmsg_command: Stringreplymsg_command: Stringinreplyto_command: Option<String>mailto: Option<String>hmail: Option<String>domainaddr: Option<String>css: Option<String>icss_url: Option<String>mcss_url: Option<String>dateformat: Option<String>indexdateformat: Option<String>stripsubject: Option<String>link_to_replies: Option<String>quote_link_string: Option<String>ihtmlheader: Option<String>ihtmlhead: Option<String>ihtmlhelpup: Option<String>ihtmlhelplow: Option<String>mhtmlheader: Option<String>attachmentlink: Option<String>bodyheader: Option<String>bodyheaderend: Option<String>unsafe_chars: Option<String>filename_base: Option<String>folder_by_date: Option<String>latest_folder: Option<String>base_url: Option<String>describe_folder: Option<String>delete_older: Option<String>delete_newer: Option<String>alts_text: Option<String>description: Option<String>theme: Option<String>append_filename: Option<String>txtsuffix: Option<String>email_address_obfuscation: booli18n: booli18n_body: booloverwrite: boolinlinehtml: boolreadone: boolreverse: boolreverse_folders: boolshowheaders: boolshowbr: boolshowreplies: boolindextable: booliquotes: booleurodate: boolgmtime: boolisodate: boolrequire_msgids: booldiscard_dup_msgids: boolusemeta: booluselock: boolietf_mbox: boollinkquotes: boolmonthly_index: boolyearly_index: boolspamprotect: boolspamprotect_id: boolattachmentsindex: boolusegdbm: boolwritehaof: boolappend: boolnonsequential: boolwarn_surpressions: boolfiles_by_thread: boolhref_detection: boolmbox_shortened: boolreport_new_file: boolreport_new_folder: booluse_sender_date: boolinline_addlink: booliso2022jp: booldelete_incremental: boolshowgenerator: boolshow_warnings: boolincrement: i32showhtml: i32show_msg_links: i32show_index_links: i32thrdlevels: i32dirmode: i32filemode: i32locktime: i32searchbackmsgnum: i32quote_hide_threshold: i32thread_file_depth: i32startmsgnum: i32msgsperfolder: i32save_alts: i32delete_level: i32progress: i32max_message_size: usizeshow_headers: HmListavoid_indices: HmListavoid_top_indices: HmListskip_headers: HmListtext_types: HmListinline_types: HmListprefered_types: HmListignore_types: HmListfilter_out: HmListfilter_require: HmListfilter_out_full_body: HmListfilter_require_full_body: HmListdeleted: HmListexpires: HmListdelete_msgnum: HmListImplementations
Sourceimpl Config
impl Config
Sourcepub fn set_string(&mut self, key: &str, val: &str) -> Result<()>
pub fn set_string(&mut self, key: &str, val: &str) -> Result<()>
Sets a string configuration value by key name.
Sourcepub fn set_switch(&mut self, key: &str, val: bool) -> Result<()>
pub fn set_switch(&mut self, key: &str, val: bool) -> Result<()>
Sets a boolean switch configuration value by key name.
Sourcepub fn set_integer(&mut self, key: &str, val: i64) -> Result<()>
pub fn set_integer(&mut self, key: &str, val: i64) -> Result<()>
Sets an integer configuration value by key name.
Sourcepub fn set_list(&mut self, key: &str, val: &str) -> Result<()>
pub fn set_list(&mut self, key: &str, val: &str) -> Result<()>
Appends whitespace-separated values to a list configuration by key name.
Sourcepub fn apply_cli_arg(&mut self, key: &str, val: &str) -> Result<()>
pub fn apply_cli_arg(&mut self, key: &str, val: &str) -> Result<()>
Applies a CLI argument, auto-detecting the value type (bool/int/string/list).
Supports key=value syntax, hm_ and set_ prefixes, and ON/OFF/YES/NO values.
Sourcepub fn post_process(&mut self)
pub fn post_process(&mut self)
Applies post-processing defaults (e.g., always-skipped headers).